@@ -681,7 +681,7 @@ class Microservice(core.Construct):
         network_load_balancer_source_autoscaling_group=None,
         stickiness_cookie_duration_in_hours=None,
         load_balancer_idle_timeout_in_seconds=None,
-        rubrik_backup=True,
+        rubrik_backup="True",
         **kwargs
     ):
         super().__init__(scope, id, **kwargs)
@@ -809,6 +809,12 @@ class Microservice(core.Construct):
             will_use_ldap and isinstance(will_use_ldap, str) and will_use_ldap.lower() == "true"
         )
 
+        to_be_backed_up = (
+            rubrik_backup
+            and isinstance(rubrik_backup, str)
+            and rubrik_backup.lower() == "true"
+        )
+
         # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Validate input params
 
         if has_additional_variables and type(additional_variables) is not dict:
@@ -873,7 +879,7 @@ class Microservice(core.Construct):
 
             # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ FAO AWS Rubrik backup tag
 
-            if rubrik_backup:
+            if to_be_backed_up:
                 Tags.of(ebs).add("RubrikBackup", "true")
             else:
                 Tags.of(ebs).add("RubrikBackup", "false")
@@ -1254,7 +1260,7 @@ class Microservice(core.Construct):
 
             # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ FAO AWS Rubrik backup tag
 
-            if rubrik_backup:
+            if to_be_backed_up:
                 Tags.of(self._efs).add("RubrikBackup", "true")
             else:
                 Tags.of(self._efs).add("RubrikBackup", "false")
@@ -1407,7 +1413,7 @@ class Microservice(core.Construct):
         # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ FAO AWS Rubrik backup tag
 
         ASG = asg.node.find_child("ASG")
-        if rubrik_backup:
+        if to_be_backed_up:
             Tags.of(ASG).add("RubrikBackup", "true", apply_to_launched_instances=True)
         else:
             Tags.of(ASG).add("RubrikBackup", "false", apply_to_launched_instances=True)
@@ -1484,7 +1490,7 @@ class Microservice(core.Construct):
                 description="EFS access from EC2 " + app_name,
             )
 
-            if rubrik_backup:
+            if to_be_backed_up:
                 rubrik_cloud_cluster_secg_id = "sg-0f80734443f5059b2"
                 production_aws_account_id = self._environments_parameters["accounts"]["production"]["id"]
                 _ec2.CfnSecurityGroupIngress(
@@ -1549,7 +1555,7 @@ class Microservice(core.Construct):
             self,
             "asg_notifications_lifecycle_hook_role",
             role_arn=aws_account["asg_cw_alerts_lc_hooks_role"],
-            mutable=True,
+            mutable=False,
         )
         notification_metadata = json.dumps(
             {"label": self._app_name + "-" + main_component_name}
